@@ -309,16 +309,7 @@ class TestQueryJob(_Base):
 
         self.assertTrue(job.cancelled())
 
-    def test_done_job_complete(self):
-        client = _make_client(project=self.PROJECT)
-        resource = self._make_resource(ended=True)
-        job = self._get_target_class().from_api_repr(resource, client)
-        job._query_results = google.cloud.bigquery.query._QueryResults.from_api_repr(
-            {"jobComplete": True, "jobReference": resource["jobReference"]}
-        )
-        self.assertTrue(job.done())
-
-    def test_done_w_timeout(self):
+    def test__done_or_raise_w_timeout(self):
         client = _make_client(project=self.PROJECT)
         resource = self._make_resource(ended=False)
         job = self._get_target_class().from_api_repr(resource, client)
@@ -326,7 +317,7 @@ class TestQueryJob(_Base):
         with mock.patch.object(
             client, "_get_query_results"
         ) as fake_get_results, mock.patch.object(job, "reload") as fake_reload:
-            job.done(timeout=42)
+            job._done_or_raise(timeout=42)
 
         fake_get_results.assert_called_once()
         call_args = fake_get_results.call_args
@@ -335,7 +326,7 @@ class TestQueryJob(_Base):
         call_args = fake_reload.call_args
         self.assertEqual(call_args.kwargs.get("timeout"), 42)
 
-    def test_done_w_timeout_and_longer_internal_api_timeout(self):
+    def test__done_or_raise_w_timeout_and_longer_internal_api_timeout(self):
         client = _make_client(project=self.PROJECT)
         resource = self._make_resource(ended=False)
         job = self._get_target_class().from_api_repr(resource, client)
@@ -344,7 +335,7 @@ class TestQueryJob(_Base):
         with mock.patch.object(
             client, "_get_query_results"
         ) as fake_get_results, mock.patch.object(job, "reload") as fake_reload:
-            job.done(timeout=5.5)
+            job._done_or_raise(timeout=5.5)
 
         # The expected timeout used is simply the given timeout, as the latter
         # is shorter than the job's internal done timeout.
@@ -357,7 +348,7 @@ class TestQueryJob(_Base):
         call_args = fake_reload.call_args
         self.assertAlmostEqual(call_args.kwargs.get("timeout"), expected_timeout)
 
-    def test_done_w_query_results_error_reload_ok_job_finished(self):
+    def test__done_or_raise_w_query_results_error_reload_ok(self):
         client = _make_client(project=self.PROJECT)
         bad_request_error = exceptions.BadRequest("Error in query")
         client._get_query_results = mock.Mock(side_effect=bad_request_error)
@@ -373,32 +364,11 @@ class TestQueryJob(_Base):
         fake_reload_method = types.MethodType(fake_reload, job)
 
         with mock.patch.object(job, "reload", new=fake_reload_method):
-            is_done = job.done()
+            job._done_or_raise()
 
-        assert is_done
         assert isinstance(job._exception, exceptions.BadRequest)
 
-    def test_done_w_query_results_error_reload_ok_job_still_running(self):
-        client = _make_client(project=self.PROJECT)
-        retry_error = exceptions.RetryError("Too many retries", cause=TimeoutError)
-        client._get_query_results = mock.Mock(side_effect=retry_error)
-
-        resource = self._make_resource(ended=False)
-        job = self._get_target_class().from_api_repr(resource, client)
-        job._exception = None
-
-        def fake_reload(self, *args, **kwargs):
-            self._properties["status"]["state"] = "RUNNING"
-
-        fake_reload_method = types.MethodType(fake_reload, job)
-
-        with mock.patch.object(job, "reload", new=fake_reload_method):
-            is_done = job.done()
-
-        assert not is_done
-        assert job._exception is None
-
-    def test_done_w_query_results_error_reload_error(self):
+    def test__done_or_raise_w_query_results_error_reload_error(self):
         client = _make_client(project=self.PROJECT)
         bad_request_error = exceptions.BadRequest("Error in query")
         client._get_query_results = mock.Mock(side_effect=bad_request_error)
@@ -409,12 +379,11 @@ class TestQueryJob(_Base):
         job.reload = mock.Mock(side_effect=reload_error)
         job._exception = None
 
-        is_done = job.done()
+        job._done_or_raise()
 
-        assert is_done
         assert job._exception is bad_request_error
 
-    def test_done_w_job_query_results_ok_reload_error(self):
+    def test__done_or_raise_w_job_query_results_ok_reload_error(self):
         client = _make_client(project=self.PROJECT)
         query_results = google.cloud.bigquery.query._QueryResults(
             properties={
@@ -430,9 +399,8 @@ class TestQueryJob(_Base):
         job.reload = mock.Mock(side_effect=retry_error)
         job._exception = None
 
-        is_done = job.done()
+        job._done_or_raise()
 
-        assert is_done
         assert job._exception is retry_error
 
     def test_query_plan(self):
@@ -1905,8 +1873,6 @@ class TestQueryJob(_Base):
         )
 
     def test_iter(self):
-        import types
-
         begun_resource = self._make_resource()
         query_resource = {
             "jobComplete": True,
